# DataLib


upload package

on modifie la version dans setup.py a la racine
on rebuild avec :
python setup.py sdist

on update sur pypi avec 
twine upload --skip-existing dist/*

user = __token__
password = via nordpass